% P16Deadtime1.m
%  REA 2011-Sep-29 12:24
% COPYRIGHT:   Aprend Technology, 2011. All rights reserved.

%% set path
workdir = 'E:\Projects\CountDetPhysics\PileupSim\';
addpath(workdir);


%% run the simulation vs. deadtime
ntrials_pileup_stats = 100;
ntrials = 100;
stats_all = zeros(ntrials,4); % mean, var for n_recorded, n_input
mean_cps = 1e6; % 1/seconds
t_ave = 1/mean_cps;%sec
t_integrate = 1.5e-3; %sec
ndeadtimes = 10;
deadtimes = linspace(0,0.5*t_ave,ndeadtimes);
statsbar = zeros(ndeadtimes,4);
for kdead = 1:ndeadtimes
    deadtime = deadtimes(kdead);
    ns_all = [];
    for ktrial = 1:ntrials
        ns= PileupStats('mean_cps',mean_cps,'deadtime',deadtime,'ntrials',ntrials_pileup_stats,'t_integrate',t_integrate);
        ns_all = [ns_all; ns];
    end
   statsbar(kdead,:) = [mean(ns_all) var(ns_all)];
   fprintf('.')
   if mod(ktrial,80)==0
       fprintf('\n');
   end
end
fprintf('\n');

%% plot mean counts and energies vs. deadtime (eta)
nbars_MC = statsbar(:,1); % mean counts with deadtime
var_MC = statsbar(:,3); % variance of counts with deadtime
etas = mean_cps*deadtimes; % lambda*tau
nbar_incident = mean_cps*t_integrate;
nbars_calc = nbar_incident./(1 + etas);
var_calc = nbar_incident./(1 + etas).^3;
fh = figure;
hold on
plot(etas,nbars_MC/nbar_incident,'ok','linewidth',1.5);
plot(etas,nbars_calc/nbar_incident,'-r','linewidth',1.5);
plot(etas,var_MC/nbar_incident,'+b','linewidth',1.5);
plot(etas,var_calc/nbar_incident,'-b','linewidth',1.5);
hold off
legend('N:Monte Carlo','N:theory','var:Monte Carlo','var:theory','location','southwest');
axis([0 0.5 0 1])
xlabel('mean_cps*deadtime','fontsize',14,'interpreter','none')
ylabel('average,variance recorded counts/incident )','fontsize',14)
set(gca,'fontsize',12,'linewidth',1.5)
set(fh,'color','w','position',[250 250 450 375])

%% export the figure as png and eps
dirname = 'E:\Projects\Blog\Posts\P16Deadtime1\'; % edit this for your computer
figno = sprintf('-f%d',fh);
fname = 'MeanVarWDeadtime';
print(figno,[dirname fname '.png'],'-dpng','-cmyk','-r100') % resolution 100 dpi
   % export as eps
exportfig(fh,[dirname fname '.eps'],'width',4,'LockAxes',0,'color','cmyk');
